# ResourceSessionStats

Resources session statistics.  A resource session refers to the communication channel between two endpoints.  ApplicationService, ServiceForwarder and FileShareService are all resources that associate communication to a specific resource with a session. 

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**total** | **int** | total number of sessions | [optional] 
**allowed** | **int** | total number of allowed sessions | [optional] 
**denied** | **int** | total number of denied sessions | [optional] 
**failed** | **int** | total number of failed sessions | [optional] 
**any string name** | **bool, date, datetime, dict, float, int, list, str, none_type** | any string name can be used but the value must be the correct type | [optional]

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


